@@ -3,19 +3,23 @@ package Sah::Schema::hexstr;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-07-09'; # DATE
+our $DATE = '2022-09-22'; # DATE
 our $DIST = 'Sah-Schemas-Str'; # DIST
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.012'; # VERSION
 
 our $schema = [str => {
     summary => 'String of bytes in hexadecimal',
     match => qr/\A(?:[0-9A-Fa-f]{2})*\z/,
 
+    prefilters => ['Str::remove_whitespace'],
+
     examples => [
         {value=>'', valid=>1},
         {value=>'a0', valid=>1},
+        {value=>'A0', valid=>1, summary=>'Uppercase digits are allowed, not coerced to lowercase'},
         {value=>'a0f', valid=>0, summary=>'Odd number of digits (3)'},
         {value=>'a0ff', valid=>1},
+        {value=>'a0 ff 61', valid=>1, summary=>'Whitespace will be removed', validated_value=>'a0ff61'},
         {value=>'a0fg', valid=>0, summary=>'Invalid hexdigit (g)'},
         {value=>'a0ff12345678', valid=>1},
     ],
@@ -37,7 +41,7 @@ Sah::Schema::hexstr - String of bytes in hexadecimal
 
 =head1 VERSION
 
-This document describes version 0.011 of Sah::Schema::hexstr (from Perl distribution Sah-Schemas-Str), released on 2022-07-09.
+This document describes version 0.012 of Sah::Schema::hexstr (from Perl distribution Sah-Schemas-Str), released on 2022-09-22.
 
 =head1 SYNOPSIS
 
@@ -47,10 +51,14 @@ This document describes version 0.011 of Sah::Schema::hexstr (from Perl distribu
 
  "a0"  # valid
 
+ "A0"  # valid (Uppercase digits are allowed, not coerced to lowercase)
+
  "a0f"  # INVALID (Odd number of digits (3))
 
  "a0ff"  # valid
 
+ "a0 ff 61"  # valid (Whitespace will be removed), becomes "a0ff61"
+
  "a0fg"  # INVALID (Invalid hexdigit (g))
 
  "a0ff12345678"  # valid
@@ -71,11 +79,11 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = "a0ff12345678";
+ $data = "a0";
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
- $data = "a0fg";
+ $data = "a0f";
  my $errmsg = $validator->($data); # => "Must match regex pattern qr(\\A(?:[0-9A-Fa-f]{2})*\\z)"
 
 Often a schema has coercion rule or default value, so after validation the
@@ -86,12 +94,12 @@ prefiltered) value:
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = "a0ff12345678";
- my $res = $validator->($data); # => ["","a0ff12345678"]
+ $data = "a0";
+ my $res = $validator->($data); # => ["","a0"]
  
  # a sample invalid data
- $data = "a0fg";
- my $res = $validator->($data); # => ["Must match regex pattern qr(\\A(?:[0-9A-Fa-f]{2})*\\z)","a0fg"]
+ $data = "a0f";
+ my $res = $validator->($data); # => ["Must match regex pattern qr(\\A(?:[0-9A-Fa-f]{2})*\\z)","a0f"]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
@@ -179,9 +187,10 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
