@@ -3,9 +3,9 @@ package Sah::Schema::str_or_aos1;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-07-09'; # DATE
+our $DATE = '2022-09-22'; # DATE
 our $DIST = 'Sah-Schemas-Str'; # DIST
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.012'; # VERSION
 
 our $schema = [any => {
     summary => 'String or array (1+ length) of (defined) string',
@@ -41,7 +41,7 @@ Sah::Schema::str_or_aos1 - String or array (1+ length) of (defined) string
 
 =head1 VERSION
 
-This document describes version 0.011 of Sah::Schema::str_or_aos1 (from Perl distribution Sah-Schemas-Str), released on 2022-07-09.
+This document describes version 0.012 of Sah::Schema::str_or_aos1 (from Perl distribution Sah-Schemas-Str), released on 2022-09-22.
 
 =head1 SYNOPSIS
 
@@ -77,7 +77,7 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = ["a"];
+ $data = "";
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
@@ -92,8 +92,8 @@ prefiltered) value:
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = ["a"];
- my $res = $validator->($data); # => ["",["a"]]
+ $data = "";
+ my $res = $validator->($data); # => ["",""]
  
  # a sample invalid data
  $data = [];
@@ -185,9 +185,10 @@ simply modify the code, then test via:
 
 If you want to build the distribution (e.g. to try to install it locally on your
 system), you can install L<Dist::Zilla>,
-L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
-Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
-beyond that are considered a bug and can be reported to me.
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
 
 =head1 COPYRIGHT AND LICENSE
 
